@@ -17,14 +17,13 @@ from typing import Any, Dict, List, Type, overload
 
 from botocore.client import ClientMeta
 
-from mypy_boto3_mediatailor.paginator import (
+from .paginator import (
     GetChannelSchedulePaginator,
     ListChannelsPaginator,
     ListPlaybackConfigurationsPaginator,
     ListSourceLocationsPaginator,
     ListVodSourcesPaginator,
 )
-
 from .type_defs import (
     AccessConfigurationTypeDef,
     AdBreakTypeDef,
@@ -85,7 +84,7 @@ class Exceptions:
 
 class MediaTailorClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/mediatailor.html#MediaTailor.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/mediatailor.html#MediaTailor.Client)
     [Show boto3-stubs documentation](./client.md)
     """
 
@@ -94,8 +93,8 @@ class MediaTailorClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/mediatailor.html#MediaTailor.Client.can_paginate)
-        [Show boto3-stubs documentation](./client.md#can-paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/mediatailor.html#MediaTailor.Client.can_paginate)
+        [Show boto3-stubs documentation](./client.md#can_paginate)
         """
 
     def create_channel(
@@ -106,8 +105,8 @@ class MediaTailorClient:
         Tags: Dict[str, str] = None,
     ) -> CreateChannelResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/mediatailor.html#MediaTailor.Client.create_channel)
-        [Show boto3-stubs documentation](./client.md#create-channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/mediatailor.html#MediaTailor.Client.create_channel)
+        [Show boto3-stubs documentation](./client.md#create_channel)
         """
 
     def create_program(
@@ -120,8 +119,8 @@ class MediaTailorClient:
         AdBreaks: List["AdBreakTypeDef"] = None,
     ) -> CreateProgramResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/mediatailor.html#MediaTailor.Client.create_program)
-        [Show boto3-stubs documentation](./client.md#create-program)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/mediatailor.html#MediaTailor.Client.create_program)
+        [Show boto3-stubs documentation](./client.md#create_program)
         """
 
     def create_source_location(
@@ -133,8 +132,8 @@ class MediaTailorClient:
         Tags: Dict[str, str] = None,
     ) -> CreateSourceLocationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/mediatailor.html#MediaTailor.Client.create_source_location)
-        [Show boto3-stubs documentation](./client.md#create-source-location)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/mediatailor.html#MediaTailor.Client.create_source_location)
+        [Show boto3-stubs documentation](./client.md#create_source_location)
         """
 
     def create_vod_source(
@@ -145,74 +144,74 @@ class MediaTailorClient:
         Tags: Dict[str, str] = None,
     ) -> CreateVodSourceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/mediatailor.html#MediaTailor.Client.create_vod_source)
-        [Show boto3-stubs documentation](./client.md#create-vod-source)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/mediatailor.html#MediaTailor.Client.create_vod_source)
+        [Show boto3-stubs documentation](./client.md#create_vod_source)
         """
 
     def delete_channel(self, ChannelName: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/mediatailor.html#MediaTailor.Client.delete_channel)
-        [Show boto3-stubs documentation](./client.md#delete-channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/mediatailor.html#MediaTailor.Client.delete_channel)
+        [Show boto3-stubs documentation](./client.md#delete_channel)
         """
 
     def delete_channel_policy(self, ChannelName: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/mediatailor.html#MediaTailor.Client.delete_channel_policy)
-        [Show boto3-stubs documentation](./client.md#delete-channel-policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/mediatailor.html#MediaTailor.Client.delete_channel_policy)
+        [Show boto3-stubs documentation](./client.md#delete_channel_policy)
         """
 
     def delete_playback_configuration(self, Name: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/mediatailor.html#MediaTailor.Client.delete_playback_configuration)
-        [Show boto3-stubs documentation](./client.md#delete-playback-configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/mediatailor.html#MediaTailor.Client.delete_playback_configuration)
+        [Show boto3-stubs documentation](./client.md#delete_playback_configuration)
         """
 
     def delete_program(self, ChannelName: str, ProgramName: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/mediatailor.html#MediaTailor.Client.delete_program)
-        [Show boto3-stubs documentation](./client.md#delete-program)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/mediatailor.html#MediaTailor.Client.delete_program)
+        [Show boto3-stubs documentation](./client.md#delete_program)
         """
 
     def delete_source_location(self, SourceLocationName: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/mediatailor.html#MediaTailor.Client.delete_source_location)
-        [Show boto3-stubs documentation](./client.md#delete-source-location)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/mediatailor.html#MediaTailor.Client.delete_source_location)
+        [Show boto3-stubs documentation](./client.md#delete_source_location)
         """
 
     def delete_vod_source(self, SourceLocationName: str, VodSourceName: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/mediatailor.html#MediaTailor.Client.delete_vod_source)
-        [Show boto3-stubs documentation](./client.md#delete-vod-source)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/mediatailor.html#MediaTailor.Client.delete_vod_source)
+        [Show boto3-stubs documentation](./client.md#delete_vod_source)
         """
 
     def describe_channel(self, ChannelName: str) -> DescribeChannelResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/mediatailor.html#MediaTailor.Client.describe_channel)
-        [Show boto3-stubs documentation](./client.md#describe-channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/mediatailor.html#MediaTailor.Client.describe_channel)
+        [Show boto3-stubs documentation](./client.md#describe_channel)
         """
 
     def describe_program(
         self, ChannelName: str, ProgramName: str
     ) -> DescribeProgramResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/mediatailor.html#MediaTailor.Client.describe_program)
-        [Show boto3-stubs documentation](./client.md#describe-program)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/mediatailor.html#MediaTailor.Client.describe_program)
+        [Show boto3-stubs documentation](./client.md#describe_program)
         """
 
     def describe_source_location(
         self, SourceLocationName: str
     ) -> DescribeSourceLocationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/mediatailor.html#MediaTailor.Client.describe_source_location)
-        [Show boto3-stubs documentation](./client.md#describe-source-location)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/mediatailor.html#MediaTailor.Client.describe_source_location)
+        [Show boto3-stubs documentation](./client.md#describe_source_location)
         """
 
     def describe_vod_source(
         self, SourceLocationName: str, VodSourceName: str
     ) -> DescribeVodSourceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/mediatailor.html#MediaTailor.Client.describe_vod_source)
-        [Show boto3-stubs documentation](./client.md#describe-vod-source)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/mediatailor.html#MediaTailor.Client.describe_vod_source)
+        [Show boto3-stubs documentation](./client.md#describe_vod_source)
         """
 
     def generate_presigned_url(
@@ -223,14 +222,14 @@ class MediaTailorClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/mediatailor.html#MediaTailor.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](./client.md#generate-presigned-url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/mediatailor.html#MediaTailor.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](./client.md#generate_presigned_url)
         """
 
     def get_channel_policy(self, ChannelName: str) -> GetChannelPolicyResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/mediatailor.html#MediaTailor.Client.get_channel_policy)
-        [Show boto3-stubs documentation](./client.md#get-channel-policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/mediatailor.html#MediaTailor.Client.get_channel_policy)
+        [Show boto3-stubs documentation](./client.md#get_channel_policy)
         """
 
     def get_channel_schedule(
@@ -241,58 +240,58 @@ class MediaTailorClient:
         NextToken: str = None,
     ) -> GetChannelScheduleResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/mediatailor.html#MediaTailor.Client.get_channel_schedule)
-        [Show boto3-stubs documentation](./client.md#get-channel-schedule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/mediatailor.html#MediaTailor.Client.get_channel_schedule)
+        [Show boto3-stubs documentation](./client.md#get_channel_schedule)
         """
 
     def get_playback_configuration(self, Name: str) -> GetPlaybackConfigurationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/mediatailor.html#MediaTailor.Client.get_playback_configuration)
-        [Show boto3-stubs documentation](./client.md#get-playback-configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/mediatailor.html#MediaTailor.Client.get_playback_configuration)
+        [Show boto3-stubs documentation](./client.md#get_playback_configuration)
         """
 
     def list_channels(
         self, MaxResults: int = None, NextToken: str = None
     ) -> ListChannelsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/mediatailor.html#MediaTailor.Client.list_channels)
-        [Show boto3-stubs documentation](./client.md#list-channels)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/mediatailor.html#MediaTailor.Client.list_channels)
+        [Show boto3-stubs documentation](./client.md#list_channels)
         """
 
     def list_playback_configurations(
         self, MaxResults: int = None, NextToken: str = None
     ) -> ListPlaybackConfigurationsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/mediatailor.html#MediaTailor.Client.list_playback_configurations)
-        [Show boto3-stubs documentation](./client.md#list-playback-configurations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/mediatailor.html#MediaTailor.Client.list_playback_configurations)
+        [Show boto3-stubs documentation](./client.md#list_playback_configurations)
         """
 
     def list_source_locations(
         self, MaxResults: int = None, NextToken: str = None
     ) -> ListSourceLocationsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/mediatailor.html#MediaTailor.Client.list_source_locations)
-        [Show boto3-stubs documentation](./client.md#list-source-locations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/mediatailor.html#MediaTailor.Client.list_source_locations)
+        [Show boto3-stubs documentation](./client.md#list_source_locations)
         """
 
     def list_tags_for_resource(self, ResourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/mediatailor.html#MediaTailor.Client.list_tags_for_resource)
-        [Show boto3-stubs documentation](./client.md#list-tags-for-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/mediatailor.html#MediaTailor.Client.list_tags_for_resource)
+        [Show boto3-stubs documentation](./client.md#list_tags_for_resource)
         """
 
     def list_vod_sources(
         self, SourceLocationName: str, MaxResults: int = None, NextToken: str = None
     ) -> ListVodSourcesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/mediatailor.html#MediaTailor.Client.list_vod_sources)
-        [Show boto3-stubs documentation](./client.md#list-vod-sources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/mediatailor.html#MediaTailor.Client.list_vod_sources)
+        [Show boto3-stubs documentation](./client.md#list_vod_sources)
         """
 
     def put_channel_policy(self, ChannelName: str, Policy: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/mediatailor.html#MediaTailor.Client.put_channel_policy)
-        [Show boto3-stubs documentation](./client.md#put-channel-policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/mediatailor.html#MediaTailor.Client.put_channel_policy)
+        [Show boto3-stubs documentation](./client.md#put_channel_policy)
         """
 
     def put_playback_configuration(
@@ -313,40 +312,40 @@ class MediaTailorClient:
         VideoContentSourceUrl: str = None,
     ) -> PutPlaybackConfigurationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/mediatailor.html#MediaTailor.Client.put_playback_configuration)
-        [Show boto3-stubs documentation](./client.md#put-playback-configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/mediatailor.html#MediaTailor.Client.put_playback_configuration)
+        [Show boto3-stubs documentation](./client.md#put_playback_configuration)
         """
 
     def start_channel(self, ChannelName: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/mediatailor.html#MediaTailor.Client.start_channel)
-        [Show boto3-stubs documentation](./client.md#start-channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/mediatailor.html#MediaTailor.Client.start_channel)
+        [Show boto3-stubs documentation](./client.md#start_channel)
         """
 
     def stop_channel(self, ChannelName: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/mediatailor.html#MediaTailor.Client.stop_channel)
-        [Show boto3-stubs documentation](./client.md#stop-channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/mediatailor.html#MediaTailor.Client.stop_channel)
+        [Show boto3-stubs documentation](./client.md#stop_channel)
         """
 
     def tag_resource(self, ResourceArn: str, Tags: Dict[str, str]) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/mediatailor.html#MediaTailor.Client.tag_resource)
-        [Show boto3-stubs documentation](./client.md#tag-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/mediatailor.html#MediaTailor.Client.tag_resource)
+        [Show boto3-stubs documentation](./client.md#tag_resource)
         """
 
     def untag_resource(self, ResourceArn: str, TagKeys: List[str]) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/mediatailor.html#MediaTailor.Client.untag_resource)
-        [Show boto3-stubs documentation](./client.md#untag-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/mediatailor.html#MediaTailor.Client.untag_resource)
+        [Show boto3-stubs documentation](./client.md#untag_resource)
         """
 
     def update_channel(
         self, ChannelName: str, Outputs: List[RequestOutputItemTypeDef]
     ) -> UpdateChannelResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/mediatailor.html#MediaTailor.Client.update_channel)
-        [Show boto3-stubs documentation](./client.md#update-channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/mediatailor.html#MediaTailor.Client.update_channel)
+        [Show boto3-stubs documentation](./client.md#update_channel)
         """
 
     def update_source_location(
@@ -357,8 +356,8 @@ class MediaTailorClient:
         DefaultSegmentDeliveryConfiguration: "DefaultSegmentDeliveryConfigurationTypeDef" = None,
     ) -> UpdateSourceLocationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/mediatailor.html#MediaTailor.Client.update_source_location)
-        [Show boto3-stubs documentation](./client.md#update-source-location)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/mediatailor.html#MediaTailor.Client.update_source_location)
+        [Show boto3-stubs documentation](./client.md#update_source_location)
         """
 
     def update_vod_source(
@@ -368,8 +367,8 @@ class MediaTailorClient:
         VodSourceName: str,
     ) -> UpdateVodSourceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/mediatailor.html#MediaTailor.Client.update_vod_source)
-        [Show boto3-stubs documentation](./client.md#update-vod-source)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/mediatailor.html#MediaTailor.Client.update_vod_source)
+        [Show boto3-stubs documentation](./client.md#update_vod_source)
         """
 
     @overload
@@ -377,13 +376,13 @@ class MediaTailorClient:
         self, operation_name: Literal["get_channel_schedule"]
     ) -> GetChannelSchedulePaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/mediatailor.html#MediaTailor.Paginator.GetChannelSchedule)[Show boto3-stubs documentation](./paginators.md#getchannelschedulepaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/mediatailor.html#MediaTailor.Paginator.GetChannelSchedule)[Show boto3-stubs documentation](./paginators.md#getchannelschedulepaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_channels"]) -> ListChannelsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/mediatailor.html#MediaTailor.Paginator.ListChannels)[Show boto3-stubs documentation](./paginators.md#listchannelspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/mediatailor.html#MediaTailor.Paginator.ListChannels)[Show boto3-stubs documentation](./paginators.md#listchannelspaginator)
         """
 
     @overload
@@ -391,7 +390,7 @@ class MediaTailorClient:
         self, operation_name: Literal["list_playback_configurations"]
     ) -> ListPlaybackConfigurationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/mediatailor.html#MediaTailor.Paginator.ListPlaybackConfigurations)[Show boto3-stubs documentation](./paginators.md#listplaybackconfigurationspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/mediatailor.html#MediaTailor.Paginator.ListPlaybackConfigurations)[Show boto3-stubs documentation](./paginators.md#listplaybackconfigurationspaginator)
         """
 
     @overload
@@ -399,11 +398,11 @@ class MediaTailorClient:
         self, operation_name: Literal["list_source_locations"]
     ) -> ListSourceLocationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/mediatailor.html#MediaTailor.Paginator.ListSourceLocations)[Show boto3-stubs documentation](./paginators.md#listsourcelocationspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/mediatailor.html#MediaTailor.Paginator.ListSourceLocations)[Show boto3-stubs documentation](./paginators.md#listsourcelocationspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_vod_sources"]) -> ListVodSourcesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/mediatailor.html#MediaTailor.Paginator.ListVodSources)[Show boto3-stubs documentation](./paginators.md#listvodsourcespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/mediatailor.html#MediaTailor.Paginator.ListVodSources)[Show boto3-stubs documentation](./paginators.md#listvodsourcespaginator)
         """
